@@ -36,7 +36,7 @@ use warnings::unused;
 
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.56.00'; # our $VERSION = '';
+$VERSION = '0.57.00'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -533,7 +533,7 @@ sub descend
 		foreach my $elm (@lines)
 		{
 			my @lineelms = split( /\s+|,/, $elm );
-			my $val = $lineelms[$#lineelms];
+			my $val = $lineelms[-1];
 			my $case = $lineelms[0];
 			{
 				if ($countelm > 0)
